@@ -1,4 +1,4 @@
-from src.jettools import dict
+from jettools import dict
 import unittest
 
 
